[jboss-cvs] JBossAS SVN: r83393 - in projects/jboss-deployers/trunk: deployers-vfs-spi/src/main/java/org/jboss/deployers/vfs/spi/structure and 1 other directory.

jboss-cvs-commits at lists.jboss.org jboss-cvs-commits at lists.jboss.org
Sat Jan 24 05:18:44 EST 2009


Author: alesj
Date: 2009-01-24 05:18:44 -0500 (Sat, 24 Jan 2009)
New Revision: 83393

Modified:
   projects/jboss-deployers/trunk/deployers-vfs-spi/src/main/java/org/jboss/deployers/vfs/spi/structure/VFSDeploymentContext.java
   projects/jboss-deployers/trunk/deployers-vfs-spi/src/main/java/org/jboss/deployers/vfs/spi/structure/VFSDeploymentUnit.java
   projects/jboss-deployers/trunk/deployers-vfs/src/main/java/org/jboss/deployers/vfs/plugins/structure/AbstractVFSDeploymentContext.java
   projects/jboss-deployers/trunk/deployers-vfs/src/main/java/org/jboss/deployers/vfs/plugins/structure/AbstractVFSDeploymentUnit.java
Log:
[JBDEPLOY-151]; fix the method names; file --> location.


Modified: projects/jboss-deployers/trunk/deployers-vfs/src/main/java/org/jboss/deployers/vfs/plugins/structure/AbstractVFSDeploymentContext.java
===================================================================
--- projects/jboss-deployers/trunk/deployers-vfs/src/main/java/org/jboss/deployers/vfs/plugins/structure/AbstractVFSDeploymentContext.java	2009-01-24 07:59:08 UTC (rev 83392)
+++ projects/jboss-deployers/trunk/deployers-vfs/src/main/java/org/jboss/deployers/vfs/plugins/structure/AbstractVFSDeploymentContext.java	2009-01-24 10:18:44 UTC (rev 83393)
@@ -286,51 +286,51 @@
       }
    }
 
-   public void prependMetaDataFile(VirtualFile... files)
+   public void prependMetaDataLocation(VirtualFile... locations)
    {
-      if (files == null)
-         throw new IllegalArgumentException("Null files");
+      if (locations == null)
+         throw new IllegalArgumentException("Null locations");
 
       List<VirtualFile> metadataLocations = getMutableMetaDataLocations();
       if (metadataLocations == null)
          metadataLocations = new ArrayList<VirtualFile>();
 
-      for (int i = files.length-1; i >= 0; --i)
+      for (int i = locations.length-1; i >= 0; --i)
       {
-         VirtualFile file = files[i];
-         if (file == null)
-            throw new IllegalArgumentException("Null virtual file in " + Arrays.toString(files));
-         metadataLocations.add(0, file);
+         VirtualFile location = locations[i];
+         if (location == null)
+            throw new IllegalArgumentException("Null virtual file in " + Arrays.toString(locations));
+         metadataLocations.add(0, location);
       }
       setMetaDataLocations(metadataLocations);
    }
 
-   public void appendMetaDataFile(VirtualFile... files)
+   public void appendMetaDataLocation(VirtualFile... locations)
    {
-      if (files == null)
-         throw new IllegalArgumentException("Null files");
+      if (locations == null)
+         throw new IllegalArgumentException("Null location");
 
       List<VirtualFile> metaDataLocations = getMutableMetaDataLocations();
       if (metaDataLocations == null)
          metaDataLocations = new ArrayList<VirtualFile>();
 
-      for (VirtualFile file : files)
+      for (VirtualFile location : locations)
       {
-         if (file == null)
-            throw new IllegalArgumentException("Null virtual file in " + Arrays.toString(files));
-         metaDataLocations.add(file);
+         if (location == null)
+            throw new IllegalArgumentException("Null virtual file in " + Arrays.toString(locations));
+         metaDataLocations.add(location);
       }
       setMetaDataLocations(metaDataLocations);
    }
 
-   public void removeMetaDataFile(VirtualFile... files)
+   public void removeMetaDataLocation(VirtualFile... locations)
    {
-      if (files == null || files.length == 0)
+      if (locations == null || locations.length == 0)
          return;
 
-      for (VirtualFile file : files)
+      for (VirtualFile location : locations)
       {
-         metaDataLocations.remove(file);
+         metaDataLocations.remove(location);
       }
    }
 

Modified: projects/jboss-deployers/trunk/deployers-vfs/src/main/java/org/jboss/deployers/vfs/plugins/structure/AbstractVFSDeploymentUnit.java
===================================================================
--- projects/jboss-deployers/trunk/deployers-vfs/src/main/java/org/jboss/deployers/vfs/plugins/structure/AbstractVFSDeploymentUnit.java	2009-01-24 07:59:08 UTC (rev 83392)
+++ projects/jboss-deployers/trunk/deployers-vfs/src/main/java/org/jboss/deployers/vfs/plugins/structure/AbstractVFSDeploymentUnit.java	2009-01-24 10:18:44 UTC (rev 83393)
@@ -69,19 +69,19 @@
       return getDeploymentContext().getMetaDataFiles(name, suffix);
    }
 
-   public void prependMetaDataFile(VirtualFile... files)
+   public void prependMetaDataLocation(VirtualFile... locations)
    {
-      getDeploymentContext().prependMetaDataFile(files);
+      getDeploymentContext().prependMetaDataLocation(locations);
    }
 
-   public void appendMetaDataFile(VirtualFile... files)
+   public void appendMetaDataLocation(VirtualFile... locations)
    {
-      getDeploymentContext().appendMetaDataFile(files);
+      getDeploymentContext().appendMetaDataLocation(locations);
    }
 
-   public void removeMetaDataFile(VirtualFile... files)
+   public void removeMetaDataLocation(VirtualFile... locations)
    {
-      getDeploymentContext().removeMetaDataFile(files);
+      getDeploymentContext().removeMetaDataLocation(locations);
    }
 
    @Override

Modified: projects/jboss-deployers/trunk/deployers-vfs-spi/src/main/java/org/jboss/deployers/vfs/spi/structure/VFSDeploymentContext.java
===================================================================
--- projects/jboss-deployers/trunk/deployers-vfs-spi/src/main/java/org/jboss/deployers/vfs/spi/structure/VFSDeploymentContext.java	2009-01-24 07:59:08 UTC (rev 83392)
+++ projects/jboss-deployers/trunk/deployers-vfs-spi/src/main/java/org/jboss/deployers/vfs/spi/structure/VFSDeploymentContext.java	2009-01-24 10:18:44 UTC (rev 83393)
@@ -85,22 +85,23 @@
    /**
     * Prepend metadata file locations.
     * 
     * @param files the files
     */
-   void prependMetaDataFile(VirtualFile... files);
+   void prependMetaDataLocation(VirtualFile... locations);
 
    /**
     * Append metadata file locations.
     *
     * @param files the files
     */
-   void appendMetaDataFile(VirtualFile... files);
+   void appendMetaDataLocation(VirtualFile... locations);
 
    /**
     * Remove metadata file locations.
     * @param files the files
     */
-   void removeMetaDataFile(VirtualFile... files);
+   void removeMetaDataLocation(VirtualFile... locations);
 
    /**
     * Gets a file from this deployment
@@ -85,22 +85,23 @@
     * Prepend metadata file locations.
     * 
-    * @param files the files
+    * @param locations the locations
     */
@@ -85,22 +85,23 @@
     * Append metadata file locations.
     *
-    * @param files the files
+    * @param locations the locations
     */
@@ -85,22 +85,23 @@
    /**
     * Remove metadata file locations.
-    * @param files the files
+    *
+    * @param locations the locations
     */

Modified: projects/jboss-deployers/trunk/deployers-vfs-spi/src/main/java/org/jboss/deployers/vfs/spi/structure/VFSDeploymentUnit.java
===================================================================
--- projects/jboss-deployers/trunk/deployers-vfs-spi/src/main/java/org/jboss/deployers/vfs/spi/structure/VFSDeploymentUnit.java	2009-01-24 07:59:08 UTC (rev 83392)
+++ projects/jboss-deployers/trunk/deployers-vfs-spi/src/main/java/org/jboss/deployers/vfs/spi/structure/VFSDeploymentUnit.java	2009-01-24 10:18:44 UTC (rev 83393)
@@ -58,22 +58,23 @@
    /**
     * Prepend metadata file locations.
     *
     * @param files the files
     */
-   void prependMetaDataFile(VirtualFile... files);
+   void prependMetaDataLocation(VirtualFile... locations);
 
    /**
     * Append metadata file locations.
     *
     * @param files the files
     */
-   void appendMetaDataFile(VirtualFile... files);
+   void appendMetaDataLocation(VirtualFile... locations);
 
    /**
     * Remove metadata file locations.
     * @param files the files
     */
-   void removeMetaDataFile(VirtualFile... files);
+   void removeMetaDataLocation(VirtualFile... locations);
 
    /**
     * Get a resource loader
@@ -58,22 +58,23 @@
     * Prepend metadata file locations.
     *
-    * @param files the files
+    * @param locations the locations
     */
@@ -58,22 +58,23 @@
     * Append metadata file locations.
     *
-    * @param files the files
+    * @param locations the locations
     */
@@ -58,22 +58,23 @@
    /**
     * Remove metadata file locations.
-    * @param files the files
+    *
+    * @param locations the locations
     */




More information about the jboss-cvs-commits mailing list